package org.xdv.clx.expr;

import org.xdv.clx.exec.ClxExecutionContext;
import org.xdv.clx.exec.ClxExecutionPoint;
import org.xdv.common.XdvValidationException;

/**
 * IFF (if and only if) - CLX element implementation.
 * 
 * @see <a href="http://www.clixml.org/clix/1.0/#iff">CLiXML - clx:iff</a>
 * @see org.xdv.clx.base.ClxConstants#TAG_IFF
 * @author Tomasz Kokoszka
 */
public class ClxIff extends ClxFormulaBinaryOperator {

    /**
     * Creates instance.
     * @param formula1 first sub-formula
     * @param formula2 secound sub-formula
     */
    public ClxIff(ClxFormula formula1, ClxFormula formula2) {
        super(formula1, formula2);
    }        

    public boolean executeFormula(ClxExecutionContext cntx) 
    throws XdvValidationException {
        boolean b1 = this.getFormula1().executeFormula(cntx);
        boolean b2 = this.getFormula2().executeFormula(cntx);
        return (b1 == b2);
    }

    public boolean executeFormula(ClxExecutionContext cntx, ClxExecutionPoint frame) 
    throws XdvValidationException {
        final State s = getExecutionState(frame);
        boolean b1;
        boolean b2;
        
        if (frame.getNext1().isFinished()) {
            b1 = s.v1;
        } else {
            b1 = this.getFormula1().executeFormula(cntx, frame.getNext1());
            s.v1 = b1;
        }
        
        //TODO is it always correct to resume secound formula when first was also resumed?
        if (frame.getNext2().isFinished()) {
            b2 = s.v2;
        } else {
            b2 = this.getFormula1().executeFormula(cntx, frame.getNext1());
            s.v2 = b2;
        }
        
        frame.setFinished();
        return (b1 == b2);
    }
    
    public String toString() {
        return "(" + getFormula1() + ") <=> (" + getFormula2() + ")";
    }
        
}
