package org.xdv.clx.extension;

import org.xdv.clx.exec.ClxExecutionContext;
import org.xdv.common.XdvValidationException;

/**
 * Error message - CLX extended element implementation.
 * <p>
 * This element is dedicated to generate validation-error message.
 * It is an extension to standard way of reporting errors defined in CLiXML 1.0. 
 * Extension is defined in <code>clix_Report.xsd</code>.
 * <br>
 * One error message may consist of may elements like this. Message can be:
 * <ul>
 *  <li>static - they are always the same, for instance {@link ClxExtErrorMessageText}
 *  <li>dynamic - their context is computed according to document context, failure point etc, 
 *      for instance {@link ClxExtErrorMessageXPath}.
 * </ul> 
 * </p>
 *
 * @see ClxExtErrorReport
 * @author Tomasz Kokoszka
 */
public interface ClxExtErrorMessage {

    /**
     * Generate error message.
     * @param cntx CLX execution context
     * @return error message; !=null
     * @throws XdvValidationException error while generating message
     */
    public String generateMessage(ClxExecutionContext cntx)
    throws XdvValidationException;
    
}
