package org.xdv.clx.operator;

import org.xdv.clx.exec.ClxExecutionContext;
import org.xdv.clx.exec.ClxExecutionPoint;
import org.xdv.clx.expr.ClxFormula;
import org.xdv.common.XdvValidationException;

/**
 * General OPERATOR CALL - CLX element implementation.
 * <br>
 * It is a call to user defined operator.
 * 
 * @see <a href="http://www.clixml.org/clix/1.0/#operator">CLiXML - clix:operator</a>
 * @see org.xdv.clx.base.ClxConstants#TAG_OPERATOR
 * @author Tomasz Kokoszka
 */

public abstract class ClxOperatorCall implements ClxFormula {
    
    /**
     * Create call.
     */
    public ClxOperatorCall() {
    }
    
    /**
     * Returns operator name.
     * @return operator name; !=null
     */
    public abstract String getOperatorName();

    public boolean executeFormula(ClxExecutionContext cntx, ClxExecutionPoint frame) 
    throws XdvValidationException {
        frame.finish();
        return executeFormula(cntx);
    }
    
    public String toString() {
        return "operatorCall([name])([params])";
    }
    
}
