package org.xdv.clx.operator;

import java.util.List;

import org.xdv.clx.builder.ClxBuilderException;
import org.xdv.xpath.XPathEngine;
import org.xdv.xpath.XPathException;

/**
 * Factory to instantiate plugin operator definition.
 * <p>
 * To define a new plugin operator:
 * <ol>
 *  <li>Implement operator behavior by extending class {@link ClxOperatorDef}.
 *  <li>Create a factory to instantiate plugin operator - {@link ClxOperatorDefFactory}.
 *  <li>Register the factory in validator factory - 
 *      {@link org.xdv.clx.base.ClxValidatorFactory#registerOperator(ClxOperatorDefFactory)}.
 * </ol>
 * Class {@link ClxXPathCondition} is a simple implementation of plugin operator. 
 * You should take a look at it before creating your first operator.
 * </p>
 * 
 * @author Tomasz Kokoszka
 */
public interface ClxOperatorDefFactory {
   
    /**
     * Returns operator name.
     * @return operator name; !=null
     */
    public String getName();
    
    /**
     * Insantiates plugin operator definition.
     * @param params call parameters, list of {@link ClxOperatorParam}
     * @param engine XPath engine (usefull if factory needs to create XPath expression)
     * @return instance of operator definition; !=null
     * @throws ClxBuilderException unable to instantiate plugin operator
     * @throws XPathException error while creating xpath expression
     */
    public ClxOperatorDef createCall(List params, XPathEngine engine) 
    throws ClxBuilderException, XPathException;

}
