package org.xdv.common;

/**
 * Validation error - describes in details why XML document is not valid.
 * Instances are created by XML validators when source XML document is not valid against
 * validation rules. 
 *
 * @author Tomasz Kokoszka
 */
public interface XdvValidationError {
    
    /** Validation error level - ERROR */
    public static final int LEVEL_ERROR = 1;
    
    /** Validation error level - WARNING */
    public static final int LEVEL_WARNING = 2;

    /** 
     * Returns error message.
     * Message descibes validation problem, why XML document is not valid. 
     * For instance it may say which rule has been violated.
     * @return Error message; !=null
     */
    public String getMessage();
    
    /**
     * Returns error level.
     * @return Error level, {@link #LEVEL_ERROR} or {@link #LEVEL_WARNING}
     */
    public int getLevel();
    
    /**
     * Returns error cause - it could be any object.
     * Usually it will be a XML node that should be modified to avoid this error.
     * @return Error cause, can be null
     */
    public Object getCause();
    
    /**
     * Return error cause type.
     * Usually it will be a type/class of error cause ({@link #getCause()}).
     * @return Object that describes type of error cause object, can be null.    
     */
    public Object getCauseType();
    
}
